{% load i18n %}
	{% if event.has_passed %}
		<p>{% trans "This event is over." %}</p>
	{% endif %}
	
	<h2>{{ event.name }}</h2>
	<p>{{ event.date_span }}</p>
	<p>{% if event.time %}{{ event.time}}{% endif %}</p>
    {% if event.description %}
        <div class="event description">
            {{ event.description|safe }}
        </div>
	{% endif %}
	{% if event.location %}
        <div class="event location">
            {{ event.location|safe }}
        </div>
	{% endif %}
	
	{% if event.get_next_upcoming %}
        <h3>{% trans "Next event" %}</h3>
            <a href="{{ event.get_next_upcoming.get_absolute_url }}">{{ event.get_next_upcoming.name }}, {{ event.get_next_upcoming.date_span }} &rarr;</a>
	{% endif %}
	
	{% if event.get_previous_upcoming %}
        <h3>{% trans "Previous event" %}</h3>
            <a href="{{ event.get_previous_upcoming.get_absolute_url }}">&larr; {{ event.get_previous_upcoming.name }}, {{ event.get_previous_upcoming.date_span }}</a>
	{% endif %}
